#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-5AUW8N0X4ZWgICkBvXYV7
key:                  postgrest-10.1.0-5AUW8N0X4ZWgICkBvXYV7
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  b24b4628f07531ee264c7c02300bed3c
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-5AUW8N0X4ZWgICkBvXYV7
depends:
    HTTP-4000.5.0-Hr1ehRcBA9g5408v2rAPFc
    Ranged-sets-0.5.0-70s2KeSLJu7HjHovvXmiMV
    aeson-2.2.2.0-Dt9IcEbIPgo3pXUjrBlJbR
    auto-update-0.1.6-1z9T2zyzYhC25XNZwV9BQp base-4.18.2.1
    base64-bytestring-1.2.1.0-FfsKFWslEOoAvWp1oz7NnG
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-Gzh99I2Ds5LB1yZuFXcZ2A
    cassava-0.5.4.1-KX8phaQMIfMHdPbtRoQSEr
    configurator-pg-0.2.11-KkZuCMzUh5K1w1sho1HpuI containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-J7vCwVWtNG4J3dQuKeCS0b
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-L0BdUYed7z7HxexWJvglCJ
    hasql-dynamic-statements-0.3.1.2-HLJA0CZ8fMFE0dsGlVZjze
    hasql-notifications-0.2.0.5-LR9h525tlk02JrCudNPvbe
    hasql-pool-0.8.0.2-AK67hw8ZqH91o6FKottrWr
    hasql-transaction-1.0.1.2-1YmxTBtikCj10SFye3LwMu
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-LSgWFg4mVle7jKIO2vdgXi
    insert-ordered-containers-0.2.5.3-94rIpKWggEVJycfdb6nv1K
    interpolatedstring-perl6-1.0.2-11tt4Ox7iGUH5szHgQmVYb
    jose-0.10.0.1-JVkTNE9GBI3LPwTZmtHsvB
    lens-5.3.4-6xqoTm4kiuC8ULAJ3RTBph
    lens-aeson-1.2.3-56yOaBFE3yt3tFr4PioVKQ mtl-2.3.1
    network-3.1.4.0-435zy6qxTBGFK5XFFiJsye
    network-uri-2.6.4.2-JJwr3105NpI16YFQY3IIVN
    optparse-applicative-0.18.1.0-ACOZXD1ji7S90GHMXot2xe
    parsec-3.1.16.1 protolude-0.3.5-2vkihuIsfvNGvAvFgt1ZVw
    regex-tdfa-1.3.2.5-8NW0m2HiVCwIy0zxjhdOWx
    retry-0.9.3.1-L1x0p7Ihvuc11HyYz9ohXT
    scientific-0.3.8.1-5Vi2IPU7qCODLsKXYeBYLH
    swagger2-2.8.10-6ptxRcabhi2H8dJEpfP2lv text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.20.1-6k45pUyQa13JRvzUHn0wS1
    vault-0.3.1.6-31ENgtX6Y6iLUNU7ZCl1xp
    vector-0.13.2.0-B5QnucNm6YY8XIvh7YleVY
    wai-3.2.4-7vzMwDkBBVH69wuxH7kNR
    wai-cors-0.2.7-DZHnTTmGUFb4wWV7I3SVTf
    wai-extra-3.1.18-FkJl3fQujq328X4evuCipJ
    wai-logger-2.5.0-9d0i4PLduDJ29qKHFYSqnH
    warp-3.4.0-9drghNnWwGm1mQJPNiEMEP

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

